@@ -1,3 +1,4 @@
+from datetime import timedelta
 import json
 import urllib.parse
 from typing import Awaitable, List
@@ -13,10 +14,18 @@ endpoint_async_file = "api/v0/pipeline/async/file"
 endpoint_async_tasks = "api/v0/pipeline/async/tasks"
 
 
-def build_request(input: Input, steps: List[Skill], include_text: True):
+def build_request(
+    input: Input, steps: List[Skill], multilingual: bool, include_text: True
+):
+    def json_default(obj):
+        if isinstance(obj, timedelta):
+            return str(obj)
+        return {k: v for k, v in obj.__dict__.items() if v is not None}
+
     request = {
         "steps": [skill.asdict() for skill in steps],
         "output_type": "json",
+        "multilingual": multilingual,
     }
     if include_text:
         request["text"] = input.text
@@ -27,7 +36,7 @@ def build_request(input: Input, steps: List[Skill], include_text: True):
             request["content_type"] = input.content_type
         if hasattr(input, "encoding") and input.encoding:
             request["encoding"] = input.encoding
-    return json.dumps(request, default=lambda x: x.__dict__)
+    return json.dumps(request, default=json_default)
 
 
 async def post_pipeline(
@@ -35,10 +44,11 @@ async def post_pipeline(
     input: Input,
     steps: List[Skill],
     api_key: str,
+    multilingual: bool,
 ) -> Awaitable[Output]:
     validate_api_key(api_key)
 
-    request = build_request(input, steps, True)
+    request = build_request(input, steps, multilingual, True)
     url = f"{oneai.URL}/{endpoint_default}"
     headers = {
         "api-key": api_key,
@@ -58,10 +68,11 @@ async def post_pipeline_async_file(
     input: Input,
     steps: List[Skill],
     api_key: str,
+    multilingual: bool,
 ) -> Awaitable[str]:
     validate_api_key(api_key)
 
-    request = build_request(input, steps, False)
+    request = build_request(input, steps, multilingual, False)
     url = f"{oneai.URL}/{endpoint_async_file}?pipeline=" + urllib.parse.quote(request)
     headers = {
         "api-key": api_key,
