@@ -376,44 +376,6 @@ class HtmlAllText(Skill):
     """
 
 
-@skillclass(
-    api_name="business-entities",
-    is_generator=True,
-    label_type="business-entity",
-    output_attr="labs",
-    output_attr1="business_entities",
-)
-class BusinessEntities(Skill):
-    """
-    ### 'Labs' Skill- this Skill is still in beta and is may produce incorrect results in some cases
-
-    deprecated- use `Pricing` instead.
-    Detects business entities (quantities, pricings) in the input
-
-    ## Output Attributes
-
-    `business_entities: list[Label]`
-        A list of `Label` objects, with detected business entities and their data
-
-    ## Example
-
-    >>> pipeline = oneai.Pipeline(steps=[
-    ...     oneai.skills.BusinessEntities()
-    ... ])
-    >>> output = pipeline.run('it costs 10 USD per barrel')
-    >>> output.business_entities
-    [oneai.Label(type=business-entity, name=pricing, data={'amount': 10.0, 'currency': 'USD', 'unit': 'barrel'}, span=[9, 26], value=10 USD per barrel)]
-    """
-
-    def __new__(cls, *args, **kwargs):
-        warn(
-            "BusinessEntities Skill is deprecated- use `Pricing` instead",
-            DeprecationWarning,
-            stacklevel=2,
-        )
-        return super().__new__(cls, *args, **kwargs)
-
-
 @skillclass(
     api_name="action-items", label_type="action-item", output_attr="action_items"
 )
@@ -496,7 +458,7 @@ class Pricing(Skill):
     ...     oneai.skills.Pricing()
     ... ])
     >>> output = pipeline.run('it costs 10 USD per barrel')
-    >>> output.pricing
+    >>> output.labs.pricing
     [oneai.Label(name=pricing, data={'amount': 10.0, 'currency': 'USD', 'unit': 'barrel'}, span=[9, 26], value=10 USD per barrel)]
     """
 
@@ -612,6 +574,30 @@ class SalesInsights(Skill):
     """
 
 
+@skillclass(
+    api_name="service-email-insights",
+    label_type="service-insights",
+    output_attr="service_insights",
+)
+class ServiceInsights(Skill):
+    """
+    Finds spans in the text with Service Insights.
+
+    ## Output Attributes
+
+    `service_insights: list[Label]`
+        A list of `Label` objects, with detected service insights
+
+    ## Example
+
+    >>> pipeline = oneai.Pipeline(steps=[
+    ...     oneai.skills.ServiceInsights()
+    ... ])
+    >>> output = pipeline.run('...')
+    >>> output.service_insights
+    """
+
+
 @skillclass(
     api_name="detect-language", label_type="detect-language", output_attr="language"
 )
@@ -674,7 +660,12 @@ class Subheading(Skill):
     """
 
 
-@skillclass(api_name="transcribe", is_generator=True, output_attr="transcription", output_attr1="words")
+@skillclass(
+    api_name="transcribe",
+    is_generator=True,
+    output_attr="transcription",
+    output_attr1="words",
+)
 @dataclass
 class Transcribe(Skill):
     """
@@ -699,6 +690,26 @@ class Transcribe(Skill):
     timestamp_per_word: bool = False
 
 
+@skillclass(api_name="clustering")
+@dataclass
+class Clustering(Skill):
+    """
+    Automatically organizes various skill labels in clusters for later analytics
+
+    ## Example
+
+    >>> pipeline = oneai.Pipeline(steps=[
+    ...     oneai.skills.Sentiments(),
+    ...     oneai.skills.Clustering(),
+    ... ])
+    >>> pipeline.run(input)
+    """
+
+    collection: str = ""
+    input_skill: str = ""
+    item_metadata: dict = ""
+
+
 class OutputAttrs:
     summary: "Output[str]" = None
     proofread: "Output[List[Utterance]]" = None
@@ -715,6 +726,7 @@ class OutputAttrs:
     sentiments: Labels = None
     topics: Labels = None
     sales_insights: Labels = None
+    service_insights: Labels = None
     action_items: Labels = None
     pricing: Labels = None
     replacements: Labels = None
